public inbox for linux-staging@lists.linux.dev
 help / color / mirror / Atom feed
From: Eric Florin <ericflorin@google.com>
To: teddy.wang@siliconmotion.com
Cc: sudipm.mukherjee@gmail.com, gregkh@linuxfoundation.org,
	 linux-fbdev@vger.kernel.org, linux-staging@lists.linux.dev,
	 linux-kernel@vger.kernel.org,
	Eric Florin <ericflorin@google.com>
Subject: [PATCH 1/6] staging: sm750fb: rename `sBase` parameter
Date: Tue, 27 May 2025 10:11:23 -0700	[thread overview]
Message-ID: <61e6984331cc7ff88a9f8207e187cd5b9ffd9c63.1748365488.git.ericflorin@google.com> (raw)
In-Reply-To: <cover.1748365488.git.ericflorin@google.com>

Rename `sBase` to `s_base` in `sm750_hw_copyarea` to conform with style
guidelines as reported by checkpatch.pl

CHECK: Avoid CamelCase: <sBase>

Signed-off-by: Eric Florin <ericflorin@google.com>
---
 drivers/staging/sm750fb/sm750_accel.c | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/drivers/staging/sm750fb/sm750_accel.c b/drivers/staging/sm750fb/sm750_accel.c
index 44b9e3fe3a41..74e4be8103ac 100644
--- a/drivers/staging/sm750fb/sm750_accel.c
+++ b/drivers/staging/sm750fb/sm750_accel.c
@@ -132,7 +132,7 @@ int sm750_hw_fillrect(struct lynx_accel *accel,
 /**
  * sm750_hw_copyarea
  * @accel: Acceleration device data
  * @sBase: Address of source: offset in frame buffer
  * @sPitch: Pitch value of source surface in BYTE
  * @sx: Starting x coordinate of source surface
  * @sy: Starting y coordinate of source surface
@@ -146,7 +146,7 @@ int sm750_hw_fillrect(struct lynx_accel *accel,
  * @rop2: ROP value
  */
 int sm750_hw_copyarea(struct lynx_accel *accel,
-		      unsigned int sBase, unsigned int sPitch,
+		      unsigned int s_base, unsigned int sPitch,
 		      unsigned int sx, unsigned int sy,
 		      unsigned int dBase, unsigned int dPitch,
 		      unsigned int Bpp, unsigned int dx, unsigned int dy,
@@ -160,7 +160,7 @@ int sm750_hw_copyarea(struct lynx_accel *accel,
 	de_ctrl = 0;
 
 	/* If source and destination are the same surface, need to check for overlay cases */
-	if (sBase == dBase && sPitch == dPitch) {
+	if (s_base == dBase && sPitch == dPitch) {
 		/* Determine direction of operation */
 		if (sy < dy) {
 			/*  +----------+
@@ -234,7 +234,7 @@ int sm750_hw_copyarea(struct lynx_accel *accel,
 	 * It is an address offset (128 bit aligned)
 	 * from the beginning of frame buffer.
 	 */
-	write_dpr(accel, DE_WINDOW_SOURCE_BASE, sBase); /* dpr40 */
+	write_dpr(accel, DE_WINDOW_SOURCE_BASE, s_base); /* dpr40 */
 
 	/*
 	 * 2D Destination Base.
@@ -132,7 +132,7 @@ int sm750_hw_fillrect(struct lynx_accel *accel,
  * sm750_hw_copyarea
  * @accel: Acceleration device data
- * @sBase: Address of source: offset in frame buffer
+ * @s_base: Address of source: offset in frame buffer
  * @sPitch: Pitch value of source surface in BYTE
  * @sx: Starting x coordinate of source surface
-- 
2.49.0.1151.ga128411c76-goog


  reply	other threads:[~2025-05-27 17:11 UTC|newest]

Thread overview: 13+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2025-05-27 17:11 [PATCH 0/6] staging: sm750fb: cleanup `sm750_hw_copyarea` Eric Florin
2025-05-27 17:11 ` Eric Florin [this message]
2025-06-19 15:29   ` [PATCH 1/6] staging: sm750fb: rename `sBase` parameter Greg KH
2025-05-27 17:11 ` [PATCH 2/6] staging: sm750fb: rename `sPitch` parameter Eric Florin
2025-06-19 15:29   ` Greg KH
2025-05-27 17:11 ` [PATCH 3/6] staging: sm750fb: rename `dBase` parameter Eric Florin
2025-06-19 15:30   ` Greg KH
2025-05-27 17:11 ` [PATCH 4/6] staging: sm750fb: rename `dPitch` parameter Eric Florin
2025-06-19 15:29   ` Greg KH
2025-05-27 17:11 ` [PATCH 5/6] staging: sm750fb: rename `Bpp` parameter Eric Florin
2025-06-19 15:30   ` Greg KH
2025-05-27 17:11 ` [PATCH 6/6] staging: sm750fb: Rename local var `nDirection` Eric Florin
2025-06-19 15:30   ` Greg KH

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=61e6984331cc7ff88a9f8207e187cd5b9ffd9c63.1748365488.git.ericflorin@google.com \
    --to=ericflorin@google.com \
    --cc=gregkh@linuxfoundation.org \
    --cc=linux-fbdev@vger.kernel.org \
    --cc=linux-kernel@vger.kernel.org \
    --cc=linux-staging@lists.linux.dev \
    --cc=sudipm.mukherjee@gmail.com \
    --cc=teddy.wang@siliconmotion.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox